%global pluginapi 3.9.0.0

Name:           claws-mail
Version:        3.9.0
Release:        1%{?dist}
Summary:        Email client and news reader based on GTK+
Group:          Applications/Internet
License:        GPLv3+
URL:            http://claws-mail.org
Source0:        http://downloads.sourceforge.net/sylpheed-claws/%{name}-%{version}.tar.bz2

# fixes from cvs
Patch0:         claws-mail-3.9.0cvs5.patch

BuildRequires:  flex, bison
BuildRequires:  glib2-devel >= 2.6.2
BuildRequires:  gtk2-devel >= 2.10.0
BuildRequires:  gnutls-devel
BuildRequires:  openldap-devel >= 2.0.7
BuildRequires:  enchant-devel
%ifnarch s390 s390x
BuildRequires:  pilot-link-devel
%endif
BuildRequires:  bzip2-devel
BuildRequires:  gpgme-devel >= 1.0.1
BuildRequires:  desktop-file-utils startup-notification-devel
BuildRequires:  pkgconfig
BuildRequires:  gettext-devel
BuildRequires:  libetpan-devel >= 0.57
BuildRequires:  compface-devel
#BuildRequires:  perl
BuildRequires:  libtool
BuildRequires:  libSM-devel
BuildRequires:  NetworkManager-glib-devel dbus-glib-devel
BuildRequires:  autoconf automake
BuildRequires:  docbook-utils docbook-utils-pdf

# These BR are what the configure script searches for to retrieve
# gnome-config --datadir
BuildRequires: gnome-libs-devel
# and whether to run gtk_update_icon_cache after installation.
#BuildRequires: libgnome-devel

# provide plugin api version (see /usr/include/claws-mail/common/version.h)
Provides:       claws-mail(plugin-api)%{?_isa} = %pluginapi

# last available in dist-f14
Obsoletes:      claws-mail-plugins-synce <= 3.7.6
Provides:       claws-mail-plugins-synce = %{version}-%{release}
# gtkhtml2 is deprecated as of f16
%if 0%{?fedora} >= 16
Obsoletes:      claws-mail-plugins-gtkhtml2-viewer <= 3.7.9
Provides:       claws-mail-plugins-gtkhtml2-viewer = %{version}-%{release}
%endif

%description
Claws Mail is an email client (and news reader), based on GTK+, featuring
quick response, graceful and sophisticated interface, easy configuration,
intuitive operation, abundant features, and extensibility.

%package        devel
Summary:        Development package for %{name}
Group:          Development/Libraries

%description    devel
The %{name}-devel package contains the header files
and pkgconfig file needed for development with %{name}.

%if !0%{?rhel}
%package plugins-dillo
Summary:        Dillo HTML viewer plugin for Claws Mail
Group:          Applications/Internet
Requires:       claws-mail(plugin-api)%{?_isa} = %pluginapi
Requires:       dillo

%description plugins-dillo
%{summary}
%endif

%package plugins-spamassassin
Summary:        Spamassassin plugin for Claws Mail
Group:          Applications/Internet
Requires:       claws-mail(plugin-api)%{?_isa} = %pluginapi
Requires:       spamassassin

%description plugins-spamassassin
%{summary}

%package plugins-pgp
Summary:        PGP plugin for signing and encrypting with Claws Mail
Group:          Applications/Internet
Requires:       claws-mail(plugin-api)%{?_isa} = %pluginapi
Requires:       pinentry-gui

%description plugins-pgp
%{summary}

%package plugins-bogofilter
Summary:        Bogofilter plugin for Claws Mail
Group:          Applications/Internet
Requires:       claws-mail(plugin-api)%{?_isa} = %pluginapi
Requires:       bogofilter

%description plugins-bogofilter
%{summary}

%package plugins-smime
Summary:        S/MIME support for Claws Mail
Group:          Applications/Internet
Requires:       claws-mail(plugin-api)%{?_isa} = %pluginapi
Requires:       claws-mail-plugins-pgp%{?_isa} = %{version}-%{release}

%description plugins-smime
This plugin handles S/MIME signed and/or encrypted mails. You can decrypt
mails, verify signatures or sign and encrypt your own mails.

%prep
%setup -q

%patch0 -p0 -b.cvs5

# guard for pluginapi
SOURCEAPI=$(grep -A 1 VERSION_NUMERIC src/common/version.h | tr -d '\n' | perl -ne 's/[\\\s]//g; m/(\d+),(\d+),(\d+),(\d+)/; print("$1.$2.$3.$4");')
[ "%pluginapi" == "$SOURCEAPI" ] || exit -1

%build
%configure --enable-ipv6 \
           --enable-ldap --enable-jpilot \
           --enable-spamassassin-plugin \
           --enable-enchant \
           --disable-dependency-tracking \
           --disable-rpath \
           --enable-compface \
           --enable-networkmanager-support \
%if 0%{?rhel}
           --disable-dillo-viewer-plugin \
%endif
           --enable-gnutls

make %{?_smp_mflags} LIBTOOL=%{_bindir}/libtool

%install
rm -rf %{buildroot}
export LIBTOOL=%{_bindir}/false
make DESTDIR=%{buildroot} install

%find_lang claws-mail

# use provided desktop file
desktop-file-install \
--add-category="Office" \
--remove-category="GTK" \
--remove-key="Encoding" \
--remove-key="Info" \
--dir=%{buildroot}%{_datadir}/applications \
%{name}.desktop

desktop-file-validate %{buildroot}/%{_datadir}/applications/%{name}.desktop

rm -f %{buildroot}%{_infodir}/dir

find %{buildroot} -type f -name "*.la" -exec rm -f {} ';'
find %{buildroot}%{_libdir}/claws-mail/plugins/ -type f -name \
"*.a" -exec rm -f {} ';'

# we include the manual in the doc section
rm -rf _tmp_manual && mkdir _tmp_manual
mv %{buildroot}%{_datadir}/doc/claws-mail/manual _tmp_manual
rm -f %{buildroot}%{_datadir}/doc/claws-mail/RELEASE_NOTES

# cleanup non utf8 files
for file in AUTHORS;
do iconv -f iso8859-1 -t utf-8 ${file} > \
 ${file}.conv && mv -f ${file}.conv ${file}
done;

# don't think we need icon-theme.cache
rm -f %{buildroot}%{_datadir}/icons/hicolor/icon-theme.cache

# set same date on config.h across builds for multilib (#340871)
touch -r NEWS %{buildroot}%{_includedir}/%{name}/config.h


%post
update-desktop-database &> /dev/null || :
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun
update-desktop-database &> /dev/null || :
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files -f claws-mail.lang
%doc ABOUT-NLS AUTHORS ChangeLog COPYING NEWS README RELEASE_NOTES TODO
%doc _tmp_manual/manual
%{_bindir}/*
%dir %{_libdir}/claws-mail
%dir %{_libdir}/claws-mail/plugins
%{_libdir}/claws-mail/plugins/trayicon.so
%{_mandir}/man1/*
%{_datadir}/applications/*
%{_datadir}/icons/*

%files devel
%{_includedir}/claws-mail/
%{_libdir}/pkgconfig/claws-mail.pc

%if !0%{?rhel}
%files plugins-dillo
%{_libdir}/claws-mail/plugins/dillo_viewer.so
%endif

%files plugins-spamassassin
%{_libdir}/claws-mail/plugins/spamassassin.so

%files plugins-pgp
%{_libdir}/claws-mail/plugins/pgp*.so
%{_libdir}/claws-mail/plugins/pgp*.deps

%files plugins-bogofilter
%{_libdir}/claws-mail/plugins/bogofilter.so

%files plugins-smime
%{_libdir}/claws-mail/plugins/smime.so
%{_libdir}/claws-mail/plugins/smime.deps

%changelog
* Mon Nov 19 2012 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.9.0-1

* Mon Oct 22 2012 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.8.1-3
- fix null-ptr crash (rhbz#862578, CVE-2012-4507)

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jul 05 2012 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.8.1-1
- version upgrade

* Sun Jan 22 2012 Michael Schwendt <mschwendt@fedoraproject.org>
- 3.8.0-3
- merge fix for expanded mimeview drag'n'drop (#783399)

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.8.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Dec 28 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.8.0-1
- version upgrade
- cleanup patches
- own plugin include directory in -devel

* Wed Nov 30 2011 Michael Schwendt <mschwendt@fedoraproject.org>
- 3.7.10-7
- merge fix from 3.7.10cvs47 for odd mimeview_start_drag crash (#748384)
- include built/installed manual and not its XML source
- add scriptlets for icon cache update
- add scriptlets for update-desktop-database (#690298)
- add BR gnome-libs-devel so gnome-config script is available
- drop ancient Obsoletes/Provides
- drop old spec sections not needed anymore

* Fri Nov 25 2011 Michael Schwendt <mschwendt@fedoraproject.org>
- 3.7.10-6
- fix for new glib2 where only glib.h must be included (#755308)

* Wed Sep 28 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.10-5
- drop unneeded plugin requires

* Tue Sep 27 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.10-4
- drop plugin api script

* Mon Sep 26 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.10-3
- make plugin api isa dependent

* Sun Sep 25 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.10-2
- change plugin dependencies to depend on plugin api version
  (rhbz#740662)

* Tue Aug 30 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.10-1
- version upgrade

* Thu Aug 04 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.9-6
- deprecate gtkhtml2 on f16 upwards

* Tue Jul 19 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.9-5
- bump for libetpan soname change

* Thu Jun 09 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.9-4
- change workaround to fix focus issues (#711257)

* Sat Jun  4 2011 Michael Schwendt <mschwendt@fedoraproject.org>
- 3.7.9-3
- merge fix for startup notification crash (#708192)

* Mon Apr 11 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.9-2
- include gnome-shell fix again (3.7.9cvs2)
- move some obsoletes from -plugins to main package
- spec cleanup

* Sun Apr 10 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.9-1
- version upgrade

* Sat Apr 09 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.9-0.3.20110409cvs
- add workaround/fix for hidden window in gnome-shell (#693846)

* Sun Apr 03 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.9-0.2.20110403cvs
- pull fix for upstream bug #2365

* Tue Mar 29 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.9-0.1.20110329cvs
- upgrade to cvs snapshot, drop cvs patches
- enhance desktop file to be option for default mailer (#690298)
- cleanup spec file

* Sun Mar 27 2011 Christopher Aillon <caillon@redhat.com> - 3.7.8-7
- Rebuild against NetworkManager 0.9

* Tue Feb 22 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.8-6
- fix for possible mouse wheel problems (#661766)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.8-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Jan 30 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.8-4
- remove icons fom /usr/share/pixmaps (#673235)
- switch to upstream desktop file

* Sun Jan 23 2011 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.8-3
- add plugin dep files to respective plugins (#667377)
- disable dillo on rhel

* Wed Dec 08 2010 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.8-2
- retire cachesaver and synce plugins
- unretire clamav plugin now called clamd

* Sat Dec 04 2010 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.8-1
- version upgrade

* Tue May 11 2010 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.6-1
- version upgrade
- require pinentry-gui instead of -gtk for more flexibility (#587326)

* Sun Apr 11 2010 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.5-2
- smime needs pgpcore (#572184)

* Mon Mar 08 2010 Karsten Hopp <karsten@redhat.com> 3.7.5-1.1
- don't buildrequire pilot-link-devel on s390(x)

* Mon Feb 08 2010 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.5-1
- version upgrade (#562353)

* Fri Jan 08 2010 Kevin Fenzi <kevin@tummy.com> 
- 3.7.4-1

* Wed Nov 25 2009 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.3-2
- fix for crash #537499

* Mon Oct 12 2009 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.3-1
- version upgrade (including gtk 2.18 fixes #527065)

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat Jul 04 2009 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.2-1
- version upgrade
- drop gssapi patch -> upstream

* Wed Jun 17 2009 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.1-2
- fix gssapi auth (#486422)

* Fri Mar 27 2009 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.1-1
- version upgrade

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Dec 30 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.7.0-1
- version upgrade

* Fri Nov 21 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.6.1-1
- version upgrade
- replace openssl by gnutls
- provide spell checking support via enchant

* Sat Oct 04 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.6.0-1
- version upgrade
- transition smime from claws-mail-plugins to claws-mail package

* Thu Jul 10 2008 Nikolay Vladimirov <nikolay@vladimiroff.com> 
- 3.5.0-2
- rebuild for libetpan

* Mon Jun 30 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.5.0-1
- version upgrade (#453405, #448750)
- completely fix (#449209)
- provide upgrade path from dropped pdf plugin

* Tue Jun 17 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.4.0-2
- rebuild for libetpan
- fix nm support
- fix BR (#449209)

* Wed Apr 23 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.4.0-1
- version upgrade

* Fri Mar 28 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.3.1-4
- apply some upstream patches (#439382)
- fix #431735

* Tue Mar 11 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.3.1-3
- add obsoletes for deprecated clamav plugin

* Mon Feb 25 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.3.1-2
- build with NetworkManager support

* Sat Feb 23 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.3.1-1
- version upgrade

* Fri Feb 08 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.3.0-1
- version upgrade
- clamav plugin move to plugins srpm

* Mon Jan 21 2008 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.2.0-3
- bump

* Sun Dec 23 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.2.0-2
- bump

* Mon Dec 17 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.2.0-1
- version upgrade

* Sun Dec 09 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.1.0-4
- fix #340871 multilib

* Sat Dec 08 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.1.0-3
- fix desktop file

* Thu Dec 06 2007 Release Engineering <rel-eng at fedoraproject dot org> - 3.1.0-2
- Rebuild for deps

* Mon Nov 19 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.1.0-1
- version upgrade

* Fri Oct 05 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.0.2-1
- version upgrade

* Fri Sep 21 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.0.1-1
- version upgrade

* Mon Sep 03 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 3.0.0-1
- version upgrade
- new license tag (upstream switch to GPLv3+)
- fix #254121 (CVE-2007-2958)

* Wed Aug 22 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 2.10.0-4
- new license tag

* Wed Jul 18 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 2.10.0-3
- build against libSM (#248675)

* Mon Jul 16 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 2.10.0-2
- add requires for bogofilter (#246125)

* Tue Jul 03 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
- 2.10.0-1
- version upgrade
- fix #246230

* Tue May 15 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.9.2-1
- version upgrade

* Sat Apr 21 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.9.1-1
- version upgrade which fixes CVE-2007-1558 (see #237293)

* Mon Apr 16 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.9.0-1
- version upgrade (should resolve #232675)
- fix BR

* Tue Mar 06 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.8.1-1
- version upgrade

* Sun Mar 04 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.8.0-2
- bump (clamav)

* Tue Feb 27 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.8.0-1
- version upgrade
- fix #228160
- devel subpackage does not require claws-mail anymore
- fix rpath issues
- fix pkg-config file

* Sun Feb 25 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.7.2-2
- bump

* Wed Feb 07 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.7.2-1
- version upgrade
- fix #223436
- another try on #221708

* Wed Jan 17 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.7.1-1
- version upgrade #222279
- fix xface support #221708

* Thu Jan 11 2007 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.7.0-1
- version upgrade

* Fri Dec 22 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.6.1-2
- fix Obsoletes/Requires

* Mon Dec 04 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.6.1-1
- version upgrade
- package is now named claws-mail instead of sylpheed-claws
- fix #218190, #218187

* Mon Nov 06 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.6.0-1
- version upgrade

* Thu Oct 19 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.5.6-1
- version upgrade

* Thu Oct 12 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.5.5-1
- version upgrade

* Sat Oct 07 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.5.3-1
- version upgrade

* Wed Sep 27 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.5.2-1
- version upgrade

* Tue Sep 26 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.5.1-1
- version upgrade
- should fix (#204340)

* Fri Sep 15 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.4.0-2
- FE6 rebuild

* Mon Jul 31 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.4.0-1
- version upgrade

* Mon Jun 26 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.3.1-1
- version upgrade

* Mon Jun 12 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.3.0-1
- version upgrade

* Fri Jun 09 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.2.3-1
- version upgrade

* Mon Jun 05 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.2.1-1
- version upgrade

* Mon May 08 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.2.0-1
- version upgrade

* Sat Apr 22 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.1.1-1
- split plugins from main package to ease requirements (#189113)
- version upgrade (#183357)
- fix libpisock (#189585)

* Wed Apr 05 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.1.0-1
- version upgrade

* Fri Mar 31 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.0.0-4
- #187383: add BR libgnomeprintui22-devel

* Thu Mar 02 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.0.0-3
- Fix .desktop 

* Thu Feb 16 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.0.0-2
- Rebuild for Fedora Extras 5

* Fri Feb 03 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.0.0-1
- version upgrade
- fix summary

* Wed Jan 18 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.0.0-0.rc4
- version upgrade

* Mon Jan 09 2006 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.0.0-0.rc3
- version upgrade

* Sun Dec 25 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.0.0-0.rc2
- version upgrade

* Sun Dec 04 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
2.0.0-0.rc1
- version upgrade

* Mon Nov 21 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.9.100-2
- drop program suffix (causes sylpheed-claws-claws bin)

* Thu Nov 17 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.9.100-1
- version upgrade

* Sat Oct 15 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.9.15-1
- version upgrade

* Fri Sep 09 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.9.14-1
- version upgrade

* Mon Aug 15 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.9.13-4
- fix files

* Mon Aug 15 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.9.13-3
- add gmp-devel BR

* Mon Aug 15 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.9.13-2
- add bzip2-devel BR

* Sun Jul 31 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.9.13-1
- upgrade
- switch s/gpgme03/gpgme/
- need libetpan

* Thu Jul 07 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.9.12-2
- add some doc
- fix pixmap installation

* Wed Jul 06 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.9.12-1
- version upgrade
- add dist tag

* Thu May 26 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.9.11-1
- change to gtk2 version

* Thu Apr 14 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.0.4-2
- minor cleanups
- remove aspell version check

* Thu Mar 31 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.0.4-1
- Version upgrade

* Wed Mar 23 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.0.3-1
- Version upgrade

* Fri Mar 18 2005 Michael Schwendt <mschwendt[AT]users.sf.net> - 1.0.1-3
- Don't include static libs in plugin directory.
- Set --with-gpgme-prefix to use relocated gpgme03 package contents.
- BR startup-notification-devel

* Sat Mar 05 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
1.0.1-2
- fixed some sylpheed/sylpheed-claws
- removed Conflictes sylpheed

* Wed Feb 09 2005 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:1.0.1-1
- version upgrade
- cleaned up BuildRequires/Requires and configure options

* Tue Dec 21 2004 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.13-1
- version upgrade
- remove old configure options for GnuPG support (moved to a new plugin now)
- enable new pgpmime-plugin

* Tue Jul 20 2004 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.12-1
- version upgrade
- lots of s/sylpheed/sylpheed-claws/

* Mon May 31 2004 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.11-0.fdr.1
- version upgrade

* Tue Mar 09 2004 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.10-0.fdr.1
- new upstream version

* Fri Feb 13 2004 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.9-0.fdr.1
- version upgrade
* Thu Jan 01 2004 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.8-0.fdr.1
- version upgrade

* Thu Dec 18 2003 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.7-0.fdr.2
- added missing defattr to devel rpm (fixes pending issue)

* Thu Nov 27 2003 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.7-0.fdr.1
- version upgrade

* Wed Oct 08 2003 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.6-0.fdr.8
- version upgrade

* Tue Sep 16 2003 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.5-0.fdr.7
- minor fixes (see #545 #2{1,2})

* Mon Sep 15 2003 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.5-0.fdr.6
- added specfile changes provided by Michael Schwendt
- made aspell-devel conditional severn only

* Fri Sep 12 2003 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.5-0.fdr.5
- version upgrade (thus devel package)
- readded aspell-devel (still only works for > severn but 'a nice to have')

* Sat Aug 30 2003 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.4-0.fdr.4
- reintroduced --enable-aspell without BuildRequires so that it will work in
  severn and just be ignored on > shrike
- changed openssl cflags (now via pkg-config)

* Wed Aug 06 2003 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.4-0.fdr.3
- upgrade to new version
- no aspell support till version >= 0.5.0 is aviable

* Sat Aug 02 2003 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.3-0.fdr.2
- Added BuildRequires openldap-devel, pilot-link-devel
- Excluded static archives
- Changed desktop file

* Fri Aug 01 2003 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
0:0.9.3-0.fdr.1
- Initial RPM release.
